import { GraphQLLanguageConfig, LanguageService, SchemaConfig, JSONSchema6 } from 'graphql-language-service';
import type { IEvent } from 'monaco-editor';
import type { FragmentDefinitionNode, GraphQLSchema } from 'graphql';
import type { FormattingOptions, ModeConfiguration, MonacoGraphQLSchemaConfig } from './typings';
export declare type MonacoGraphQLAPIOptions = {
    languageId: string;
    schemaConfig: SchemaConfig;
    modeConfiguration: ModeConfiguration;
    formattingOptions: FormattingOptions;
};
export declare type SchemaEntry = {
    schema: GraphQLSchema;
    documentString?: string;
    introspectionJSONString?: string;
};
export declare class MonacoGraphQLAPI {
    private _onDidChange;
    private _onSchemaLoaded;
    private _onSchemaConfigChange;
    private _schemaCache;
    private _schemaConfig;
    private _formattingOptions;
    private _modeConfiguration;
    private _languageId;
    private _documentString;
    private _externalFragmentDefinitions;
    private _langService;
    constructor({ languageId, schemaConfig, modeConfiguration, formattingOptions, }: MonacoGraphQLAPIOptions);
    get onDidChange(): IEvent<MonacoGraphQLAPI>;
    get onSchemaLoaded(): IEvent<MonacoGraphQLAPI>;
    get onSchemaConfigChange(): IEvent<MonacoGraphQLAPI>;
    get parse(): (text: string, options?: import("graphql").ParseOptions | undefined) => import("graphql").DocumentNode;
    get langService(): LanguageService | null;
    private get _currentSchemaId();
    private get _currentSchemaEntry();
    getSchemaConfig(): GraphQLLanguageConfig;
    getVariablesJSONSchema(uri: string, documentText: string): Promise<JSONSchema6 | null>;
    private loadSchema;
    private cacheSchema;
    private get schemaReset();
    getSchema(): Promise<SchemaEntry | null>;
    changeSchema(): void;
    reloadSchema(): Promise<void>;
    get languageId(): string;
    get modeConfiguration(): ModeConfiguration;
    get schemaConfig(): MonacoGraphQLSchemaConfig;
    get formattingOptions(): FormattingOptions;
    get externalFragmentDefinitions(): string | FragmentDefinitionNode[] | null;
    get hasSchema(): boolean;
    setSchemaConfig(options: SchemaConfig): void;
    updateSchemaConfig(options: Partial<SchemaConfig>): void;
    setSchemaUri(schemaUri: string): void;
    setSchema(schema: GraphQLSchema): void;
    setExternalFragmentDefinitions(externalFragmentDefinitions: string | FragmentDefinitionNode[]): void;
    setModeConfiguration(modeConfiguration: ModeConfiguration): void;
    setFormattingOptions(formattingOptions: FormattingOptions): void;
}
export declare const modeConfigurationDefault: Required<ModeConfiguration>;
export declare const schemaDefault: MonacoGraphQLSchemaConfig;
export declare const formattingDefaults: FormattingOptions;
//# sourceMappingURL=api.d.ts.map