import { MonacoGraphQLAPI, schemaDefault, formattingDefaults, modeConfigurationDefault, } from './api';
export { MonacoGraphQLAPI, modeConfigurationDefault };
import * as monaco from 'monaco-editor';
export * from './typings';
export const LANGUAGE_ID = 'graphql';
export async function initialize({ schemaConfig, formattingOptions, modeConfiguration, }) {
    monaco.languages.register({
        id: LANGUAGE_ID,
        mimetypes: ['application/graphql', 'text/graphql'],
    });
    const api = new MonacoGraphQLAPI({
        languageId: LANGUAGE_ID,
        schemaConfig: {
            ...schemaDefault,
            ...schemaConfig,
        },
        formattingOptions: {
            ...formattingDefaults,
            ...formattingOptions,
            prettierConfig: {
                ...formattingDefaults.prettierConfig,
                ...formattingOptions?.prettierConfig,
            },
        },
        modeConfiguration: {
            ...modeConfigurationDefault,
            ...modeConfiguration,
        },
    });
    const graphqlMode = await getMode();
    graphqlMode.setupMode(api);
    if (api.schemaConfig.loadSchemaOnInit) {
        api.getSchema().catch(console.error);
    }
    return api;
}
function getMode() {
    return import('./graphqlMode');
}
//# sourceMappingURL=monaco.contribution.js.map